##  Prerequisites
Before you start, do the following:
  * Learn about the SSO configuration process in [SSO Configuration Process](https://help.sap.com/docs/leanix/ea/sso-configuration-process?locale=en-US&state=PRODUCTION&version=CLOUD).


For additional information, visit the [Okta website![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.okta.com%2Fproducts%2Fsingle-sign-on%2F "https://www.okta.com/products/single-sign-on/").
